@@ -2,7 +2,7 @@
 Date         : 2023-11-02 17:34:28
 Author       : BDFD,bdfd2005@gmail.com
 Github       : https://github.com/bdfd
-LastEditTime : 2023-11-28 14:03:08
+LastEditTime : 2023-11-30 12:15:50
 LastEditors  : BDFD
 Description  : 
 FilePath     : \execdata\format\__init__.py
@@ -12,3 +12,5 @@ from ._data_conversion import convint
 from ._data_conversion import convfloat
 
 from ._format_data import fill_zeros
+from ._format_data import concat_transformed_df
+from ._format_data import concat_inversed_df
